@@ -90,13 +90,28 @@ class LeggiDiItalia:
         self.extension = extension
         self.check_filters()
         self.build_headers()
+        self.build_search_query()
+        self.build_directory_path()
 
     def check_filters(self):
         if self.judicial_bodies is None and self.sections is None and self.location is None:
             Console(stderr=True).print('No filter was provided.\nUse --help for more info.')
             raise typer.Exit()
 
-    def build_search_query(self, start='0', rows='0'):
+    def build_headers(self):
+        path = Path('ldi_cookie.txt')
+        if path.is_file():
+            self.headers['Cookie'] = path.open(mode='r').read()
+
+    def build_directory_path(self):
+        filters_to_join = [self.judicial_bodies, self.sections, self.location]
+        directory = '_'.join(
+            ['&'.join(filter.split(',')).replace(' ', '').lower() for filter in filters_to_join if filter is not None])
+
+        self.directory_path = Path('/'.join((self.path, directory)))
+        self.directory_path.mkdir(exist_ok=True, parents=True)
+
+    def build_search_query(self):
         base_query = """{"mode":"AND","items":[{"mode":"AND","items":[{"field":"operasez","mode":"IN","value":["60","46","47","55","78","59","07"]},{"field":"tipo","mode":"EQUAL","value":"giurisprudenza/sentenze"}]}]}"""
         if self.judicial_bodies is not None:
             base_query = base_query[
@@ -113,23 +128,12 @@ class LeggiDiItalia:
                          :-2] + ''',{"field":"localita_ft","mode":"EQUAL","value":"''' + self.location + '''"}''' + base_query[
                                                                                                                     -2:]
         self.search_params['query'] = base_query
-        self.search_params['start'] = str(start)
-        self.search_params['rows'] = str(rows)
+
+    def pagination_query(self, page):
+        self.search_params['start'] = page[0]
+        self.search_params['rows'] = page[1]
         return self.search_params
 
     def build_export_query(self, ids):
         self.export_params['ids'] = ids
         return self.export_params
-
-    def build_directory_path(self):
-        filters_to_join = [self.judicial_bodies, self.sections, self.location]
-        directory = '_'.join(
-            ['&'.join(filter.split(',')).replace(' ', '').lower() for filter in filters_to_join if filter is not None])
-
-        self.directory_path = Path('/'.join((self.path, directory)))
-        self.directory_path.mkdir(exist_ok=True, parents=True)
-
-    def build_headers(self):
-        path = Path('ldi_cookie.txt')
-        if path.is_file():
-            self.headers['Cookie'] = path.open(mode='r').read()
